import type { I18nConfig } from '../services/i18n';
/**
 * @see https://vuestic.dev/en/services/i18n
 *
 * Composable, that allows user to redefine text values used in Vuestic components.
 *
 * @example
 *
 * Use `mergeIntoConfig` if your i18n locale changed to change text values inside Vuestic components.
 *
 * ```js
 * import { useI18nConfig } from 'vuestic-ui'
 * import { useI18n } from 'vue-i18n'
 *
 * const { locale, messages } = useI18n()
 * const { mergeIntoConfig } = useI18nConfig()
 *
 * watch(locale, (newLocale) => {
 *  mergeIntoConfig(messages[newLocale])
 * })
 * ```
 */
export declare const useI18nConfig: () => {
    config: import("vue").ComputedRef<I18nConfig>;
    mergeIntoConfig: (newConfig: Partial<I18nConfig>) => void;
};
