import type { HSLObject, HEXObject, RGBObject } from 'colortranslator';
export type ColorInput = string | HEXObject | HSLObject | RGBObject;
export declare const isCSSVariable: (strColor: string) => boolean;
export declare const cssVariableName: (colorName: string) => string;
export declare const normalizeColorName: (colorName: string) => string;
export declare const colorToRgba: (color: ColorInput, opacity: number) => string;
export declare const getColorLightness: (color: ColorInput) => number;
export declare const getBoxShadowColor: (color: ColorInput, opacity?: number) => string;
export declare const getBoxShadowColorFromBg: (background: ColorInput, opacity?: number) => string;
export declare const getHoverColor: (color: ColorInput, opacity?: number) => string;
export declare const getFocusColor: (color: ColorInput, opacity?: number) => string;
export declare const shiftHSLAColor: (color: ColorInput, offset: {
    h?: number;
    s?: number;
    l?: number;
    a?: number;
}) => string;
export declare const setHSLAColor: (color: ColorInput, newColor: {
    h?: number;
    s?: number;
    l?: number;
    a?: number;
}) => string;
/**
 * This method guesses second color for gradient based on first one.
 * Calculation method should differ for different colors, so we split color circle
 * in zones.
 *
 * @param color
 */
export declare const shiftGradientColor: (color: ColorInput) => string;
export declare const getGradientBackground: (color: string) => string;
export declare const getStateMaskGradientBackground: (color: string, maskColor: string, maskOpacity: number) => string;
/**
 * Check if color is valid hsl, hsla, rga, rgba or hex color
 * Taken from https://www.regextester.com/103656
 * Check options <or> isCSSVariable(prop) <or> CSS.supports('color', prop) deleted due to problems with SSR and opacity
 * Details are in the discussion: https://github.com/epicmaxco/vuestic-ui/pull/1589
 * @param strColor
 */
export declare const isColor: (strColor: string) => boolean;
export declare const applyColors: (color1: ColorInput, color2: ColorInput) => string;
export declare const isColorTransparent: (color: ColorInput) => boolean;
